s6: the s6-fdholder-deletec program
Keywords: s6 s6-fdholder fd-holding fd-holder fd delete deletion unix socket activation

s6
Software
skarnet.org

# The `s6-fdholder-deletec` program

`s6-fdholder-deletec` talks to a fd-holding daemon on its open descriptors 6 and 7, and tells it to close a file descriptor it's currently holding.

## Interface

         s6-fdholder-deletec [ -t timeout ] id

- s6-fdholder-deletec expects to talk to a listening s6-fdholderd program on its descriptors 6 and 7.
- It tells the server to close the file descriptor that has been stored with identifier id.
- It then exits 0, or 1 if the server returned an error.

## Options

- `-t timeout` : if the operation cannot be processed in timeout milliseconds, then fail with an error message. Communications with the server should be near-instant, so this option is only here to protect users against programming errors.

## Notes

- s6-fdholder-deletec is the "internal" version of s6-fdholder-delete. It simply expects to be run as a UCSPI client, i.e. talking to the server over descriptors 6 and 7, instead of connecting to the server itself.
- The error messages for the s6-fdholder suite are explained here.